@@ -36,7 +36,7 @@ int muroard_client_init(void) {
 
 #ifdef MUROARD_FEATURE_INTERNAL_CLIENT
  muroard_g_client[0].state  = CLIENT_STATE_INTERNAL;
- muroard_g_client[0].sock   = -1;
+ muroard_g_client[0].sock   = MUROARD_HANDLE_INVALID;
  muroard_g_client[0].stream = -1;
 #endif
 
@@ -57,7 +57,7 @@ int muroard_client_free(void) {
  return ret;
 }
 
-int muroard_client_new(int sock) {
+int muroard_client_new(muroard_handle_t sock) {
  int i;
 
  if ( muroard_network_nonblock(sock) == -1 )
@@ -97,7 +97,7 @@ int muroard_client_delete(int id) {
    ret = -1;
  }
 
- if ( muroard_g_client[id].sock != -1 ) {
+ if ( muroard_g_client[id].sock != MUROARD_HANDLE_INVALID ) {
   muroard_network_close(muroard_g_client[id].sock);
  }
 
@@ -106,10 +106,10 @@ int muroard_client_delete(int id) {
  return ret;
 }
 
-int muroard_client_exec(int id) {
- int sock = muroard_g_client[id].sock;
+muroard_handle_t muroard_client_exec(int id) {
+ muroard_handle_t sock = muroard_g_client[id].sock;
 
- muroard_g_client[id].sock  = -1;
+ muroard_g_client[id].sock  = MUROARD_HANDLE_INVALID;
  muroard_g_client[id].state = CLIENT_STATE_EXECED;
 
  return sock;
@@ -117,7 +117,7 @@ int muroard_client_exec(int id) {
 
 int muroard_client_handle(int id) {
  struct muroard_message m;
- int sock = muroard_g_client[id].sock;
+ muroard_handle_t sock = muroard_g_client[id].sock;
  int ret  = 0;
 #ifdef MUROARD_FEATURE_VOLUME_CONTROL
  uint16_t volume;
@@ -512,13 +512,13 @@ int muroard_client_handle_server_oinfo(int id, struct muroard_message * mes) {
 
 #ifdef MUROARD_FEATURE_CMD_PASSFH
 int muroard_client_handle_passfh(int id, struct muroard_message * mes) {
- int fh;
+ muroard_handle_t fh;
 
  mes->datalen = 0;
 
  fh = muroard_network_recvfh(muroard_g_client[id].sock);
 
- if ( fh == -1 )
+ if ( fh == MUROARD_HANDLE_INVALID )
   return -1;
 
  if ( muroard_network_nonblock(fh) == -1 ) {
@@ -531,7 +531,7 @@ int muroard_client_handle_passfh(int id, struct muroard_message * mes) {
   return -1;
  }
 
- if ( muroard_stream_get_sock(mes->stream) != -1 ) {
+ if ( muroard_stream_get_sock(mes->stream) != MUROARD_HANDLE_INVALID ) {
   muroard_network_close(fh);
   return -1;
  }
@@ -773,7 +773,7 @@ int muroard_client_handle_caps(int id, struct muroard_message * mes) {
 
 #ifdef MUROARD_FEATURE_CMD_SERVER_INFO
 int muroard_client_handle_server_info(int id, struct muroard_message * mes) {
- const char * version = "muroard/" PACKAGE_VERSION " <" DEVICE_VENDOR_STRING ">" DISTRIBUTION_VERSION_STRING;
+ const char * version = MUROARD_VERSION;
  const size_t len = strlen(version);
 
  (void)id, (void)mes;
