@@ -39,16 +39,16 @@
 
 struct muroard_client {
  int state;
- int sock;
  int stream;
+ muroard_handle_t sock;
 } muroard_g_client[MUROARD_MAX_CLIENTS];
 
 int muroard_client_init(void);
 int muroard_client_free(void);
-int muroard_client_new(int sock);
+int muroard_client_new(muroard_handle_t sock);
 int muroard_client_delete(int id);
 int muroard_client_handle(int id);
-int muroard_client_exec(int id);
+muroard_handle_t muroard_client_exec(int id);
 
 int muroard_client_handle_new_stream(int id, struct muroard_message * mes);
 
