@@ -35,7 +35,7 @@
 #define MUROARD_DRIVER_WMM         5
 #define MUROARD_DRIVER_SNDIO       6
 
-int muroard_driver_init(char * dev);
+int muroard_driver_init(const char * dev);
 int muroard_driver_free(void);
 int muroard_driver_write(int16_t * data);
 
