@@ -33,7 +33,7 @@ ao_device        * driver_ao_device = NULL;
 #define DRIVER_HAVE_FREE
 #define DRIVER_HAVE_WRITE
 
-int muroard_driver_init(char * dev) {
+int muroard_driver_init(const char * dev) {
  ao_sample_format  format;
  int               driver;
 #ifdef HAVE_LIBAO_MATRIX
@@ -51,7 +51,7 @@ int muroard_driver_init(char * dev) {
  if (driver < 0)
   return -1;
 
- memset(&format, 0, sizeof(format));
+ muroard_memzero(&format, sizeof(format));
 
  format.bits        = 16;
  format.channels    = muroard_g_sa_channels;
