@@ -35,7 +35,7 @@ struct sio_hdl * driver_sndio_hdl = NULL;
 
 /* TODO: FIXME: this driver needs error handlung! */
 
-int muroard_driver_init(char * dev) {
+int muroard_driver_init(const char * dev) {
  struct sio_par par;
 
  sio_initpar(&par);
