@@ -34,7 +34,7 @@ int muroard_dsp_mixer(int16_t * out, int16_t ** in, size_t num) {
  switch (num) {
 #ifdef MUROARD_FEATURE_OPTIMIZE
   case 0:
-    memset(out, 0, muroard_g_abuffer_size);
+    muroard_memzero(out, muroard_g_abuffer_size);
    break;
 /* This case can not happen as the waveform code will use zero-copy.
   case 1:
