@@ -38,6 +38,9 @@
 // Support help text? (--help/-h):
 #define MUROARD_FEATURE_HELP_TEXT
 
+// Support version text? (--version):
+#define MUROARD_FEATURE_VERSION_TEXT
+
 // Support progress arguments (argv[]):
 #define MUROARD_FEATURE_ARGV
 
@@ -117,6 +120,9 @@
 // Should we support M$'s RIFF/WAVE container?:
 #define MUROARD_FEATURE_CODECFILTER_RIFF_WAVE
 
+// Should we support Xiph's Ogg Vorbis?:
+#define MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+
 /*********************************************************/
 /* below you find the stream settings                    */
 /*********************************************************/
@@ -127,6 +133,11 @@
 // Should we support stream position handling?:
 #define MUROARD_FEATURE_POSITION
 
+// Should we support re-reading and re-writing?:
+// This does not work on win32 as we need nonblocking sockets
+// for this to work correctly.
+#define MUROARD_FEATURE_REREADWRITE
+
 /*********************************************************/
 /* below you find client and stream options              */
 /*********************************************************/
@@ -140,6 +151,9 @@
 // Support internal client (used for background streams):
 #define MUROARD_FEATURE_INTERNAL_CLIENT
 
+// Support sources and additional sinks?:
+#define MUROARD_FEATURE_SOURCES
+
 /*********************************************************/
 /* below you find driver options                         */
 /*********************************************************/
@@ -297,6 +311,9 @@
 // support for UNIX sockets:
 #define MUROARD_FEATURE_SOCKET_UNIX
 
+// support for DECnet sockets:
+#define MUROARD_FEATURE_SOCKET_DECNET
+
 // default type for listen sockets:
 // ensure that this type is enabled above!
 // keep undefined to use internal default.
@@ -308,6 +325,9 @@
 // default address of IPv4 host to listen on:
 #define MUROARD_DEFAULT_LISTEN_ADDR_INET   "localhost"
 
+// default address of DECnet host to listen on:
+#define MUROARD_DEFAULT_LISTEN_ADDR_DECNET "::roar"
+
 // default port (only IPv4) to listen on:
 // port 16002 is RoarAudio default
 #define MUROARD_DEFAULT_LISTEN_PORT        16002
