@@ -37,31 +37,34 @@ void muroard_usage (void) {
  printf("Usage: muroard [OPTIONS]...\n\n");
 
  printf("Misc Options:\n\n");
- printf(""
+ printf(" -h --help             - Print this help\n"
+#ifdef MUROARD_FEATURE_VERSION_TEXT
+        "    --version          - Print version string\n"
+#endif
 #ifdef MUROARD_FEATURE_DAEMONIZE
-        " --daemon              - Bring the server into background after init\n"
+        "    --daemon           - Bring the server into background after init\n"
 #endif
 #ifdef MUROARD_FEATURE_STANDBY
-        " --autostandby         - Start in autostandby mode"
+        "    --autostandby      - Start in autostandby mode"
 #ifdef MUROARD_FEATURE_STANDBY_AUTOMODE
                                   " (default)\n"
 #else
                                   "\n"
 #endif
-        " --no-autostandby      - Do not start in autostandby mode"
+        "    --no-autostandby   - Do not start in autostandby mode"
 #ifdef MUROARD_FEATURE_STANDBY_AUTOMODE
                                   "\n"
 #else
                                   " (default)\n"
 #endif
 
-        " --standby             - Start in standby mode"
+        "    --standby          - Start in standby mode"
 #ifdef MUROARD_FEATURE_STANDBY_ACTIVE
                                   " (default)\n"
 #else
                                   "\n"
 #endif
-        " --no-standby          - Do not start in standby mode"
+        "    --no-standby       - Do not start in standby mode"
 #ifdef MUROARD_FEATURE_STANDBY_ACTIVE
                                   "\n"
 #else
@@ -81,8 +84,19 @@ void muroard_usage (void) {
         " -O  --odevice DEV     - Set output device\n"
        );
 
- printf("\nNetwork Options:\n\n");
+#ifdef MUROARD_FEATURE_SOURCES
+ printf("\nSources Options:\n\n");
  printf(
+        " -S DEV                - Set source device or filename\n"
+        " -sC CHANS             - Set source number of channels\n"
+        " -sB BITS              - Set source number of bits\n"
+        " -sE CODEC             - Set source codec (no symbolic names)\n"
+//        " -sD DIR               - Set source direction: in or out\n"
+       );
+#endif
+
+ printf("\nNetwork Options:\n\n");
+ printf(""
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
         "     --no-listen       - Disable listen socket\n"
 #endif
@@ -98,6 +112,9 @@ void muroard_usage (void) {
 #endif
 #ifdef MUROARD_FEATURE_SOCKET_INET
         " -t  --tcp             - Use TCP listen socket\n"
+#endif
+#ifdef MUROARD_FEATURE_SOCKET_DECNET
+        " -n  --decnet          - Use DECnet listen socket\n"
 #endif
        );
 }
@@ -105,6 +122,12 @@ void muroard_usage (void) {
 #define muroard_usage()
 #endif
 
+#ifdef MUROARD_FEATURE_VERSION_TEXT
+void muroard_version (void) {
+ printf("Version: %s\n", MUROARD_VERSION);
+}
+#endif
+
 // signal handler:
 #ifdef MUROARD_FEATURE_SIGNALS
 void muroard_on_sig(int sig) {
@@ -224,18 +247,33 @@ int muroard_main_initonly (int argc, char * argv[]) {
  int daemon = 0;
 #endif
 #ifdef MUROARD_FEATURE_CLIENT_FH
- int    c_sock[MUROARD_MAX_CLIENTS];
- int    c_sock_count = 0;
+ muroard_handle_t c_sock[MUROARD_MAX_CLIENTS];
+ int              c_sock_count = 0; // this is int so we can use 'i' in the for(){}.
 #endif
 #endif
+#ifdef MUROARD_FEATURE_SOURCES
+ const char * s_filename = NULL;
+ int          s_dir = STREAM_DATADIR_IN;
+ struct muroar_audio_info s_info = {.channels = muroard_g_sa_channels, .bits = 16, .codec = MUROAR_CODEC_PCM_S};
+#endif
 
 #ifdef MUROARD_FEATURE_ARGV
  for (i = 1; i < argc; i++) {
   k = argv[i];
 
+#ifdef MUROARD_FEATURE_HELP_TEXT
   if ( !strcmp(k, "--help") || !strcmp(k, "-h") ) {
    muroard_usage();
    return 0;
+#else
+  if ( 0 ) {
+   // noop.
+#endif
+#ifdef MUROARD_FEATURE_VERSION_TEXT
+  } else if ( !strcmp(k, "--version") ) {
+   muroard_version();
+   return 0;
+#endif
 #ifdef MUROARD_FEATURE_DAEMONIZE
   } else if ( !strcmp(k, "--daemon") ) {
    daemon = 1;
@@ -256,6 +294,39 @@ int muroard_main_initonly (int argc, char * argv[]) {
    muroard_g_sa_channels = atoi(argv[++i]);
   } else if ( !strcmp(k, "--odevice") || !strcmp(k, "-O") ) {
    o_dev  = argv[++i];
+#ifdef MUROARD_FEATURE_SOURCES
+  } else if ( !strcmp(k, "-S") ) {
+   s_filename = argv[++i];
+  } else if ( !strcmp(k, "-sC") ) {
+   s_info.channels = atoi(argv[++i]);
+  } else if ( !strcmp(k, "-sB") ) {
+   s_info.bits = atoi(argv[++i]);
+  } else if ( !strcmp(k, "-sE") ) {
+   s_info.codec = atoi(argv[++i]);
+  } else if ( !strcmp(k, "-sD") ) {
+   i++;
+   if ( !strcmp(argv[i], "in") ) {
+    s_dir = STREAM_DATADIR_IN;
+   } else if ( !strcmp(argv[i], "out") ) {
+    s_dir = STREAM_DATADIR_OUT;
+   } else {
+    fprintf(stderr, "Error: Unknown stream direction: %s.\n", argv[i]);
+    return 1;
+   }
+/* TODO: this is currently not supported as the init for the streams will overwrite it.
+  } else if ( !strcmp(k, "-sN") ) {
+   if ( s_filename != NULL ) {
+    if ( muroard_stream_new_source(s_filename, s_dir, &s_info) == -1 ) {
+     fprintf(stderr, "Error: Can not add source/sink: %s.\n", s_filename);
+    }
+   }
+   s_filename = NULL;
+   s_dir = STREAM_DATADIR_IN;
+   s_info.channels = muroard_g_sa_channels;
+   s_info.bits = 16;
+   s_info.codec = MUROAR_CODEC_PCM_S;
+*/
+#endif
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
   } else if ( !strcmp(k, "--no-listen") ) {
    n_no_listen = 1;
@@ -277,6 +348,10 @@ int muroard_main_initonly (int argc, char * argv[]) {
   } else if ( !strcmp(k, "--tcp") || !strcmp(k, "-t") ) {
     n_type = MUROARD_NETWORK_TYPE_INET;
 #endif
+#ifdef MUROARD_FEATURE_SOCKET_DECNET
+  } else if ( !strcmp(k, "--decnet") || !strcmp(k, "-n") ) {
+    n_type = MUROARD_NETWORK_TYPE_DECNET;
+#endif
 #endif
   } else {
    muroard_usage();
@@ -296,6 +371,14 @@ int muroard_main_initonly (int argc, char * argv[]) {
   return 3;
  }
 
+#ifdef MUROARD_FEATURE_SOURCES
+ if ( s_filename != NULL ) {
+  if ( muroard_stream_new_source(s_filename, s_dir, &s_info) == -1 ) {
+   fprintf(stderr, "Error: Can not add source/sink: %s.\n", s_filename);
+  }
+ }
+#endif
+
 #ifdef MUROARD_FEATURE_CLIENT_FH
  for (i = 0; i < c_sock_count; i++) {
   if ( muroard_client_new(c_sock[i]) == -1 ) {
