@@ -30,7 +30,15 @@
 #include "features.h" /* feature config */
 #include "deps.h"     /* calc deps of config options */
 
+// MUROARD_VERSION can not be used by externel applications as it depends
+// on parameters passed by the Makefile.
+#define MUROARD_VERSION "muroard/" PACKAGE_VERSION " <" DEVICE_VENDOR_STRING ">" DISTRIBUTION_VERSION_STRING
+
+#define muroard_handle_t int
+#define MUROARD_HANDLE_INVALID -1
+
 #include <string.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 
@@ -45,6 +53,10 @@
 #include <sys/un.h>
 #endif
 #include <netdb.h>
+#ifdef MUROARD_FEATURE_SOCKET_DECNET
+#include <netdnet/dn.h>
+#include <netdnet/dnetdb.h>
+#endif
 #endif
 
 #if !defined(__WIN32) && !defined(TARGET_MICROCONTROLLER)
@@ -64,6 +76,14 @@
 #include <sys/stat.h>
 #endif
 
+#ifdef __OpenBSD__
+#include <sys/uio.h>
+#endif
+
+#if defined(MUROARD_FEATURE_CODECFILTER) && defined(MUROARD_FEATURE_CODECFILTER_OGG_VORBIS)
+#include <vorbis/vorbisfile.h>
+#endif
+
 #include <muroar.h>   /* Roar header file */
 
 #include "para.h"     /* server parameter and config */
@@ -85,6 +105,9 @@
 
 int muroard_g_alive;
 
+void muroard_usage (void);
+void muroard_version (void);
+
 void muroard_init_signals(void);
 void muroard_daemonize(void);
 int  muroard_init(void);
