@@ -29,12 +29,13 @@
 
 #define MUROARD_NETWORK_TYPE_UNIX      1
 #define MUROARD_NETWORK_TYPE_INET      2
+#define MUROARD_NETWORK_TYPE_DECNET    3
 
 int muroard_network_init(void);
 int muroard_network_free(void);
 int muroard_network_prefree(void);
 
-int muroard_network_listen(int type, char * addr, int port);
+int muroard_network_listen(int type, const char * addr, int port);
 
 enum muroard_blocking {
  MUROARD_BLOCKING_NONE =  0,
@@ -52,11 +53,11 @@ int muroard_network_check(enum muroard_blocking blocking);
 #define muroard_network_read(fh,buf,len)  read((fh), (buf), (len))
 #define muroard_network_write(fh,buf,len) write((fh), (buf), (len))
 #define muroard_network_close(fh)         close((fh))
-int muroard_network_nonblock(int fh);
+int muroard_network_nonblock(muroard_handle_t fh);
 #endif
 
 #ifdef MUROARD_FEATURE_CMD_PASSFH
-int muroard_network_recvfh(int fh);
+muroard_handle_t muroard_network_recvfh(muroard_handle_t fh);
 #endif
 
 #endif
