@@ -49,7 +49,10 @@ size_t muroard_g_abuffer_size = 0; /* we will calc this at runtime */
 /*********************************************************/
 
 #ifdef MUROARD_FEATURE_SOCKET_LISTEN
-int muroard_g_listen_socket   = -1; /* listen socket to use */
+muroard_handle_t muroard_g_listen_socket   = MUROARD_HANDLE_INVALID; /* listen socket to use */
+#endif
+#ifdef MUROARD_FEATURE_SOCKET_LISTEN_SOCKTYPE
+int muroard_g_listen_type = -1;
 #endif
 
 //ll
