@@ -25,11 +25,11 @@
  */
 
 #include "muroard.h"
-#ifndef __WIN32
+#if !defined(__WIN32) && !defined(HAVE_LIB_YIFFC)
 #include <sched.h>
 #endif
 
-int muroard_proto_recv(int sock, struct muroard_message * mes) {
+int muroard_proto_recv(muroard_handle_t sock, struct muroard_message * mes) {
  unsigned char header[10];
 #ifndef __WIN32
  ssize_t ret = -1;
@@ -76,7 +76,7 @@ int muroard_proto_recv(int sock, struct muroard_message * mes) {
  return 0;
 }
 
-int muroard_proto_send(int sock, struct muroard_message * mes) {
+int muroard_proto_send(muroard_handle_t sock, struct muroard_message * mes) {
  unsigned char header[10];
 
 // fprintf(stderr, "MSG OUT: ver=0, cmd=%i, stream=%i, pos=%u, datalen=%u\n", mes->cmd, mes->stream, mes->pos, mes->datalen);
