@@ -27,7 +27,7 @@
 #include "muroard.h"
 
 int muroard_stream_init(void) {
- memset(muroard_g_stream, 0, sizeof(muroard_g_stream)); // unused = 0
+ muroard_memzero(muroard_g_stream, sizeof(muroard_g_stream)); // unused = 0
  return 0;
 }
 
@@ -106,6 +106,9 @@ int muroard_stream_new(int client, int dir, struct muroar_audio_info * info) {
 #endif
 #ifdef MUROARD_FEATURE_CODECFILTER_RIFF_WAVE
   case MUROAR_CODEC_RIFF_WAVE:
+#endif
+#ifdef MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+  case MUROAR_CODEC_OGG_VORBIS:
 #endif
     _NEED_CF = info->codec;
     info->codec = MUROAR_CODEC_PCM;
@@ -142,7 +145,7 @@ int muroard_stream_new(int client, int dir, struct muroar_audio_info * info) {
  for (i = 0; i < MUROARD_MAX_STREAMS; i++) {
   if ( muroard_g_stream[i].state == STREAM_STATE_UNUSED ) {
    stream = &(muroard_g_stream[i]);
-   memset(stream, 0, sizeof(*stream));
+   muroard_memzero(stream, sizeof(*stream));
    stream->state    = STREAM_STATE_UNUSED;
    stream->iobuf    = NULL;
 
@@ -161,6 +164,12 @@ int muroard_stream_new(int client, int dir, struct muroar_audio_info * info) {
     case MUROAR_CODEC_RIFF_WAVE:
       stream->cf_read = muroard_cf_riff_wave_read;
      break;
+#endif
+#ifdef MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+    case MUROAR_CODEC_OGG_VORBIS:
+      stream->cf_read  = muroard_cf_ogg_vorbis_read;
+      stream->cf_close = muroard_cf_ogg_vorbis_close;
+     break;
 #endif
     default: return -1;
    }
@@ -182,7 +191,7 @@ int muroard_stream_new(int client, int dir, struct muroar_audio_info * info) {
       if ( (stream->iobuf = muroard_malloc(muroard_g_abuffer_size)) == NULL ) {
        return -1;
       }
-      memset(stream->iobuf, 0, muroard_g_abuffer_size); // clean memory to avoid noise
+      muroard_memzero(stream->iobuf, muroard_g_abuffer_size); // clean memory to avoid noise
      break;
 #ifdef MUROARD_FEATURE_MONITOR
     case MUROAR_MONITOR_WAVE:
@@ -231,7 +240,7 @@ int muroard_stream_new(int client, int dir, struct muroar_audio_info * info) {
 
    //fprintf(stderr, "%s:%i: dir=%i\n", __FILE__, __LINE__, dir);
 
-   stream->sock   = -1;
+   stream->sock   = MUROARD_HANDLE_INVALID;
    stream->client = client;
    stream->dir    = dir;
 
@@ -281,7 +290,7 @@ int muroard_stream_delete(int id) {
   muroard_g_client[stream->client].stream = -1;
  }
 
- if ( stream->sock != -1 ) {
+ if ( stream->sock != MUROARD_HANDLE_INVALID ) {
   muroard_network_close(stream->sock);
  }
 
@@ -294,9 +303,9 @@ int muroard_stream_delete(int id) {
 }
 
 int muroard_stream_exec(int id) {
- int sock;
+ muroard_handle_t sock;
 
- if ( (sock = muroard_client_exec(muroard_g_stream[id].client)) == -1 )
+ if ( (sock = muroard_client_exec(muroard_g_stream[id].client)) == MUROARD_HANDLE_INVALID )
   return -1;
 
  muroard_g_stream[id].sock  = sock;
@@ -305,6 +314,47 @@ int muroard_stream_exec(int id) {
  return 0;
 }
 
+#ifdef MUROARD_FEATURE_REREADWRITE
+ssize_t muroard_stream_network_read(int id, void * buf, size_t len) {
+ muroard_handle_t fh = muroard_stream_get_sock(id);
+ ssize_t done = 0;
+ ssize_t ret;
+
+ if ( fh == MUROARD_HANDLE_INVALID || buf == NULL )
+  return -1;
+
+ while (len) {
+  if ( (ret = muroard_network_read(fh, buf, len)) < 1 )
+   return done;
+
+  done += ret;
+  buf   = (char *)buf + ret;
+  len  -= ret;
+ }
+
+ return done;
+}
+ssize_t muroard_stream_network_write(int id, const void * buf, size_t len) {
+ muroard_handle_t fh = muroard_stream_get_sock(id);
+ ssize_t done = 0;
+ ssize_t ret;
+
+ if ( fh == MUROARD_HANDLE_INVALID || buf == NULL )
+  return -1;
+
+ while (len) {
+  if ( (ret = muroard_network_write(fh, buf, len)) < 1 )
+   return done;
+
+  done += ret;
+  buf   = (const char *)buf + ret;
+  len  -= ret;
+ }
+
+ return done;
+}
+#endif
+
 int muroard_stream_read(int id) {
  register struct muroard_stream * stream = &(muroard_g_stream[id]);
  ssize_t len;
@@ -338,7 +388,7 @@ int muroard_stream_read(int id) {
   muroard_stream_delete(id);
   return -1;
  } else {
-  memset(((void*)stream->iobuf)+len, 0, muroard_g_abuffer_size - len);
+  muroard_memzero(((void*)stream->iobuf)+len, muroard_g_abuffer_size - len);
  }
 
 #ifdef MUROARD_FEATURE_POSITION
@@ -371,13 +421,12 @@ int muroard_stream_write(int id, int16_t * buf) {
  register struct muroard_stream * stream = &(muroard_g_stream[id]);
  ssize_t len;
  size_t  writesize = muroard_g_abuffer_size;
- int     sock;
 #if defined(MUROARD_FEATURE_DOWNSCALE_OUTPUT) || defined(MUROARD_FEATURE_DOWNMIX_OUTPUT) || defined(MUROARD_FEATURE_BYTE_SWAP)
  size_t   need_buf = 0;
 #define _NEED_BUF need_buf
 #endif
 
- if ( (sock = muroard_stream_get_sock(id)) == -1 )
+ if ( muroard_stream_get_sock(id) == MUROARD_HANDLE_INVALID )
   return -1;
 
 #ifdef MUROARD_FEATURE_DOWNSCALE_OUTPUT
@@ -429,7 +478,7 @@ int muroard_stream_write(int id, int16_t * buf) {
  }
 #endif
 
- len = muroard_network_write(sock, buf, writesize);
+ len = muroard_stream_network_write(id, buf, writesize);
 
  if ( len < 1 ) {
   muroard_stream_delete(id);
@@ -583,4 +632,42 @@ int muroard_stream_cksupport(struct muroar_audio_info * info, int datadir) {
 }
 #endif
 
+#ifdef MUROARD_FEATURE_SOURCES
+int muroard_stream_new_source(const char * filename, int dir, struct muroar_audio_info * info) {
+ int stream;
+ int flags = O_NONBLOCK;
+ int fh;
+
+ if ( dir == STREAM_DATADIR_IN ) {
+  flags |= O_RDONLY;
+ } else if ( dir == STREAM_DATADIR_OUT ) {
+#ifndef O_LARGEFILE
+#define O_LARGEFILE 0
+#endif
+  flags |= O_WRONLY|O_CREAT|O_LARGEFILE|O_APPEND;
+ } else {
+ }
+
+ fh = open(filename, flags, 0666);
+ if ( fh == -1 )
+  return -1;
+
+ stream = muroard_stream_new(0, dir, info);
+ if ( stream == -1 )
+  return -1;
+
+ if ( muroard_stream_move_client(stream, 0) == -1 ) {
+  muroard_stream_delete(stream);
+  return -1;
+ }
+
+ if ( muroard_stream_set_sock(stream, fh) == -1 ) {
+  muroard_stream_delete(stream);
+  return -1;
+ }
+
+ return stream;
+}
+#endif
+
 //ll
