@@ -44,8 +44,8 @@ struct muroar_audio_info {
 
 struct muroard_stream {
  // general data and IO:
+ muroard_handle_t sock;
  int state;
- int sock;
  int client;
  int datadir;
  // Stream level data:
@@ -74,6 +74,13 @@ struct muroard_stream {
   struct {
    ssize_t dataoffset, headeroffset;
   } au;
+#endif
+#ifdef MUROARD_FEATURE_CODECFILTER_OGG_VORBIS
+  struct {
+   int opened;
+   int stream_id;
+   OggVorbis_File vf;
+  } ogg_vorbis;
 #endif
  } cf_data;
 #endif
@@ -98,9 +105,13 @@ int muroard_stream_move_client(int id, int client);
 int muroard_stream_cksupport(struct muroar_audio_info * info, int datadir);
 #endif
 
+#ifdef MUROARD_FEATURE_SOURCES
+int muroard_stream_new_source(const char * filename, int dir, struct muroar_audio_info * info);
+#endif
+
 #define muroard_stream_exist(id)       (((uint16_t)(id)) == (uint16_t)-1 || muroard_g_stream[(id)].state == STREAM_STATE_UNUSED ?  0   : 1)
-#define muroard_stream_get_sock(id)    (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED ? -1   : muroard_g_stream[(id)].sock)
-#define muroard_stream_set_sock(id, s) (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED || muroard_g_stream[(id)].sock != -1 ? \
+#define muroard_stream_get_sock(id)    (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED ? MUROARD_HANDLE_INVALID : muroard_g_stream[(id)].sock)
+#define muroard_stream_set_sock(id, s) (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED || muroard_g_stream[(id)].sock != MUROARD_HANDLE_INVALID ? \
                                 -1  : (muroard_g_stream[(id)].sock = (s)) && 0)
 
 #define muroard_stream_get_iobuf(id)   (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED ? NULL : muroard_g_stream[(id)].iobuf)
@@ -110,7 +121,13 @@ int muroard_stream_cksupport(struct muroar_audio_info * info, int datadir);
 #define muroard_stream_get_volume(id)  (muroard_g_stream[(id)].state == STREAM_STATE_UNUSED ? -1   : muroard_g_stream[(id)].volume)
 #endif
 
-#define muroard_stream_network_read(id,buf,len) muroard_network_read(muroard_g_stream[(id)].sock, (buf), (len))
+#ifdef MUROARD_FEATURE_REREADWRITE
+ssize_t muroard_stream_network_read(int id, void * buf, size_t len);
+ssize_t muroard_stream_network_write(int id, const void * buf, size_t len);
+#else
+#define muroard_stream_network_read(id,buf,len) muroard_network_read(muroard_stream_get_sock((id)), (buf), (len))
+#define muroard_stream_network_write(id,buf,len) muroard_network_write(muroard_stream_get_sock((id)), (buf), (len))
+#endif
 
 #endif
 
